@@ -12,7 +12,7 @@ def restaurant_id(restaurant_id = 1, length = 6):
 
 def invoice_id(invoice_id = 1, length = 6):
 	# invoice ID
-	return "ES" + datetime.datetime.today().year + str(invoice_id).zfill(length)
+	return "ES" + str(datetime.datetime.today().year) + str(invoice_id).zfill(length)
 
 def reservation_code(res_code_id = 1, length = 6):
 	# reservation Code
